@@ -57,8 +57,9 @@ namespace vsgXchange
         static constexpr const char* print_assimp = "print_assimp";                       /// int
         static constexpr const char* external_textures = "external_textures";             /// bool
         static constexpr const char* external_texture_format = "external_texture_format"; /// TextureFormat enum
-        static constexpr const char* sRGBTextures = "sRGBTextures";                       /// bool
         static constexpr const char* culling = "culling";                                 /// bool, insert cull nodes, defaults to true
+        static constexpr const char* vertex_color_space = "vertex_color_space";           /// CoordinateSpace {sRGB or LINEAR} to assume when reading vertex colors
+        static constexpr const char* material_color_space = "material_color_space";       /// CoordinateSpace {sRGB or LINEAR} to assume when reading materials colors
 
         bool readOptions(vsg::Options& options, vsg::CommandLine& arguments) const override;
 
