@@ -435,7 +435,7 @@ SamplerData SceneConverter::convertTexture(const aiMaterial& material, aiTexture
         samplerImage.sampler->addressModeW = getWrapMode(wrapMode[2]);
         samplerImage.sampler->anisotropyEnable = VK_TRUE;
         samplerImage.sampler->maxAnisotropy = 16.0f;
-        samplerImage.sampler->maxLod = samplerImage.data->properties.maxNumMipmaps;
+        samplerImage.sampler->maxLod = static_cast<float>(samplerImage.data->properties.mipLevels);
 
         if (samplerImage.sampler->maxLod <= 1.0)
         {
@@ -609,13 +609,13 @@ void SceneConverter::convert(const aiMaterial* material, vsg::DescriptorConfigur
 
         unsigned int maxValue = 1;
         float strength = 1.0f;
-        if (aiGetMaterialFloatArray(material, AI_MATKEY_SHININESS, &mat.shininess, &maxValue) == AI_SUCCESS)
-        {
-            maxValue = 1;
-            if (aiGetMaterialFloatArray(material, AI_MATKEY_SHININESS_STRENGTH, &strength, &maxValue) == AI_SUCCESS)
-                mat.shininess *= strength;
-        }
-        else
+        // any factors for other material parameters get multiplied in by AssImp before we see them, but the specular factor is different
+        // doing it like this means it's happening after conversion to the target colour space, which is sensible, but not necessarily what old data expects
+        if (aiGetMaterialFloatArray(material, AI_MATKEY_SHININESS_STRENGTH, &strength, &maxValue) == AI_SUCCESS)
+            mat.specular *= strength;
+
+        maxValue = 1;
+        if (aiGetMaterialFloatArray(material, AI_MATKEY_SHININESS, &mat.shininess, &maxValue) != AI_SUCCESS)
         {
             mat.shininess = 0.0f;
             mat.specular.set(0.0f, 0.0f, 0.0f, 0.0f);
@@ -676,18 +676,6 @@ void SceneConverter::convert(const aiMaterial* material, vsg::DescriptorConfigur
         // https://github.com/KhronosGroup/glTF/blob/main/specification/2.0/figures/gltfOverview-2.0.0d.png
         convertedMaterial.assignDescriptor("jointMatrices", jointSampler->jointMatrices);
     }
-
-    if (sharedObjects)
-    {
-        for (auto& ds : convertedMaterial.descriptorSets)
-        {
-            if (ds)
-            {
-                sharedObjects->share(ds->descriptors);
-                sharedObjects->share(ds);
-            }
-        }
-    }
 }
 
 vsg::ref_ptr<vsg::Data> SceneConverter::createIndices(const aiMesh* mesh, unsigned int numIndicesPerFace, uint32_t numIndices)
@@ -841,7 +829,6 @@ void SceneConverter::convert(const aiMesh* mesh, vsg::ref_ptr<vsg::Node>& node)
         config->assignArray(vertexArrays, "vsg_TexCoord0", VK_VERTEX_INPUT_RATE_INSTANCE, texcoord);
     }
 
-
     vsg::AttributeBinding& colorBinding = config->shaderSet->getAttributeBinding("vsg_Color");
     targetVertexColorSpace = colorBinding.coordinateSpace;
 
@@ -852,7 +839,7 @@ void SceneConverter::convert(const aiMesh* mesh, vsg::ref_ptr<vsg::Node>& node)
         vsg::convert(colors->size(), &(colors->at(0)), sourceVertexColorSpace, targetVertexColorSpace);
         config->assignArray(vertexArrays, "vsg_Color", VK_VERTEX_INPUT_RATE_VERTEX, colors);
 
-        vsg::info("vsg::convert(", colors, ", ", sourceVertexColorSpace, ", ", targetVertexColorSpace, ")");
+        vsg::debug("vsg::convert(", colors, ", ", sourceVertexColorSpace, ", ", targetVertexColorSpace, ")");
     }
     else
     {
@@ -860,7 +847,7 @@ void SceneConverter::convert(const aiMesh* mesh, vsg::ref_ptr<vsg::Node>& node)
         vsg::convert(colors->value(), sourceVertexColorSpace, targetVertexColorSpace);
         config->assignArray(vertexArrays, "vsg_Color", VK_VERTEX_INPUT_RATE_INSTANCE, colors);
 
-        vsg::info("vsg::convert(", colors, ", ", sourceVertexColorSpace, ", ", targetVertexColorSpace, ")");
+        vsg::debug("vsg::convert(", colors, ", ", sourceVertexColorSpace, ", ", targetVertexColorSpace, ")");
     }
 
     if (mesh->HasBones() && jointSampler)
@@ -1040,8 +1027,6 @@ vsg::ref_ptr<vsg::Node> SceneConverter::visit(const aiScene* in_scene, vsg::ref_
         sourceMaterialColorSpace = vsg::CoordinateSpace::sRGB;
     }
 
-    vsg::info("before sourceVertexColorSpace = ", sourceVertexColorSpace, ", sourceMaterialColorSpace = ", sourceMaterialColorSpace);
-
     if (options)
     {
 
@@ -1049,8 +1034,7 @@ vsg::ref_ptr<vsg::Node> SceneConverter::visit(const aiScene* in_scene, vsg::ref_
         options->getValue(assimp::material_color_space, sourceMaterialColorSpace);
     }
 
-    vsg::info("after sourceVertexColorSpace = ", sourceVertexColorSpace, ", sourceMaterialColorSpace = ", sourceMaterialColorSpace);
-
+    vsg::debug("vsgXchange::assimp sourceVertexColorSpace = ", sourceVertexColorSpace, ", sourceMaterialColorSpace = ", sourceMaterialColorSpace);
 
     std::string name = scene->mName.C_Str();
 
