@@ -206,6 +206,13 @@ vsg::ref_ptr<vsg::Object> curl::Implementation::read(const vsg::Path& filename,
     curl_easy_setopt(_curl, CURLOPT_URL, filename.string().c_str());
     curl_easy_setopt(_curl, CURLOPT_WRITEDATA, (void*)&sstr);
 
+#if CURL_AT_LEAST_VERSION(7, 21, 6)
+    // "" means any encoding curl supports
+    curl_easy_setopt(_curl, CURLOPT_ACCEPT_ENCODING, "");
+#else
+    curl_easy_setopt(_curl, CURLOPT_ENCODING, "");
+#endif
+
     uint32_t sslOptions = 0;
 #if defined(_WIN32) && defined(CURLSSLOPT_NATIVE_CA)
     sslOptions |= CURLSSLOPT_NATIVE_CA;
@@ -222,7 +229,7 @@ vsg::ref_ptr<vsg::Object> curl::Implementation::read(const vsg::Path& filename,
         long response_code = 0;
         result = curl_easy_getinfo(_curl, CURLINFO_RESPONSE_CODE, &response_code);
 
-        if (result == 0 && response_code >= 200 && response_code<300) // successful responses.
+        if (result == 0 && response_code >= 200 && response_code < 300) // successful responses.
         {
             // success
             auto local_options = vsg::clone(options);
@@ -250,7 +257,6 @@ vsg::ref_ptr<vsg::Object> curl::Implementation::read(const vsg::Path& filename,
                     fout << sstr.rdbuf();
                 }
             }
-
         }
         else
         {
@@ -259,7 +265,7 @@ vsg::ref_ptr<vsg::Object> curl::Implementation::read(const vsg::Path& filename,
     }
     else
     {
-        object = vsg::ReadError::create(vsg::make_string("vsgXchange::curl could not read file ", filename, ", result = ", result, ", ",curl_easy_strerror(result)));
+        object = vsg::ReadError::create(vsg::make_string("vsgXchange::curl could not read file ", filename, ", result = ", result, ", ", curl_easy_strerror(result)));
     }
 
     if (_curl) curl_easy_cleanup(_curl);
