@@ -587,6 +587,7 @@ vsg::ref_ptr<vsg::Object> freetype::Implementation::read(const vsg::Path& filena
     std::multiset<GlyphQuad> sortedGlyphQuads;
 
     bool hasSpace = false;
+    FT_ULong charcodeSpace = 32;
 
     // collect all the sizes of the glyphs
     FT_ULong max_charcode = 0;
@@ -597,8 +598,6 @@ vsg::ref_ptr<vsg::Object> freetype::Implementation::read(const vsg::Path& filena
         charcode = FT_Get_First_Char(face, &glyph_index);
         while (glyph_index != 0)
         {
-            charcode = FT_Get_Next_Char(face, charcode, &glyph_index);
-
             error = FT_Load_Glyph(face, glyph_index, load_flags);
             if (error) continue;
 
@@ -610,33 +609,34 @@ vsg::ref_ptr<vsg::Object> freetype::Implementation::read(const vsg::Path& filena
                 static_cast<unsigned int>(ceil(float(face->glyph->metrics.width) * freetype_pixel_size_scale)),
                 static_cast<unsigned int>(ceil(float(face->glyph->metrics.height) * freetype_pixel_size_scale))};
 
-            if (charcode == 32) hasSpace = true;
+            if (charcode == charcodeSpace) hasSpace = true;
 
             sortedGlyphQuads.insert(quad);
+
+            charcode = FT_Get_Next_Char(face, charcode, &glyph_index);
         }
     }
 
     if (!hasSpace)
     {
-        FT_ULong charcode = 32;
-        FT_UInt glyph_index = FT_Get_Char_Index(face, charcode);
+        FT_UInt glyph_index = FT_Get_Char_Index(face, charcodeSpace);
 
-        if (glyph_index != 0)
+        error = FT_Load_Glyph(face, glyph_index, load_flags);
+        if (!error)
         {
-            error = FT_Load_Glyph(face, glyph_index, load_flags);
+            GlyphQuad quad{
+                charcodeSpace,
+                glyph_index,
+                static_cast<unsigned int>(ceil(float(face->glyph->metrics.width) * freetype_pixel_size_scale)),
+                static_cast<unsigned int>(ceil(float(face->glyph->metrics.height) * freetype_pixel_size_scale))};
 
-            if (!error)
-            {
-                GlyphQuad quad{
-                    charcode,
-                    glyph_index,
-                    static_cast<unsigned int>(ceil(float(face->glyph->metrics.width) * freetype_pixel_size_scale)),
-                    static_cast<unsigned int>(ceil(float(face->glyph->metrics.height) * freetype_pixel_size_scale))};
+            sortedGlyphQuads.insert(quad);
 
-                sortedGlyphQuads.insert(quad);
-
-                hasSpace = true;
-            }
+            hasSpace = true;
+        }
+        else
+        {
+            vsg::warn("freetype::Implementation::read(..) No space glyph.");
         }
     }
 
